@@ -1,9 +1,12 @@
 # Django
-from django.http import HttpResponse, StreamingHttpResponse
+# Standard Library
+from typing import Any, Dict, Iterable, Union
+
+from django.http import HttpRequest, HttpResponse, StreamingHttpResponse
 from django.template.response import TemplateResponse
 
 # Local
-from .renderers import render_turbo_frame, render_turbo_stream
+from .renderers import Action, render_turbo_frame, render_turbo_stream
 
 
 class TurboStreamResponseMixin:
@@ -23,7 +26,7 @@ class TurboStreamStreamingResponse(TurboStreamResponseMixin, StreamingHttpRespon
 class TurboStreamResponse(TurboStreamResponseMixin, HttpResponse):
     """Basic turbo-stream response."""
 
-    def __init__(self, content=b"", *, action, target, **kwargs):
+    def __init__(self, content: str = "", *, action: Action, target: str, **kwargs):
         super().__init__(
             render_turbo_stream(action, target, content), **kwargs,
         )
@@ -42,7 +45,16 @@ class TurboStreamTemplateResponse(TurboStreamResponseMixin, TemplateResponse):
 
     is_turbo_stream = True
 
-    def __init__(self, request, template, context, *, action, target, **kwargs):
+    def __init__(
+        self,
+        request: HttpRequest,
+        template: Union[str, Iterable[str]],
+        context: Dict[str, Any],
+        *,
+        action: Action,
+        target: str,
+        **kwargs
+    ):
 
         super().__init__(
             request,
@@ -60,7 +72,7 @@ class TurboStreamTemplateResponse(TurboStreamResponseMixin, TemplateResponse):
         self._action = action
 
     @property
-    def rendered_content(self):
+    def rendered_content(self) -> str:
         return render_turbo_stream(
             action=self._action, target=self._target, content=super().rendered_content
         )
@@ -69,7 +81,7 @@ class TurboStreamTemplateResponse(TurboStreamResponseMixin, TemplateResponse):
 class TurboFrameResponse(HttpResponse):
     """Handles turbo-frame template response."""
 
-    def __init__(self, content=b"", *, dom_id, **kwargs):
+    def __init__(self, content: str = "", *, dom_id: str, **kwargs):
         super().__init__(
             render_turbo_frame(dom_id, content), **kwargs,
         )
@@ -87,7 +99,15 @@ class TurboFrameTemplateResponse(TemplateResponse):
 
     is_turbo_frame = True
 
-    def __init__(self, request, template, context, *, dom_id, **kwargs):
+    def __init__(
+        self,
+        request: HttpRequest,
+        template: Union[str, Iterable[str]],
+        context: Dict[str, Any],
+        *,
+        dom_id,
+        **kwargs
+    ):
 
         super().__init__(
             request,
@@ -99,5 +119,5 @@ class TurboFrameTemplateResponse(TemplateResponse):
         self._dom_id = dom_id
 
     @property
-    def rendered_content(self):
+    def rendered_content(self) -> str:
         return render_turbo_frame(self._dom_id, super().rendered_content)
